local config = {}

function error(message, err)
	print("Sh_ONTIME_HANDLER", "ERROR", message, err)
end

function info(message)
	print("Sh_ONTIME_HANDLER", "INFO", message)
end

function readConfig()
	local JSONData = file.Read("config.json", "DATA")
	if JSONData == nil then
		error("Config not found!")
	end

	config = util.JSONToTable(JSONData)
	if config == nil || config.apiURL == nil || config.apiKey == nil then
		error("Invalid config!")
		exit()
	end
	info("Config loaded")
end

local function getUserJoinedMutation(id)
    return util.TableToJSON({
        query = "mutation { userJoinedGameServer { userJoined(input: { ident: \"" .. id .. "\" }) { id } } }"
    })
end

local function getUserLeftMutation(id)
    return util.TableToJSON({
        ['query'] = "mutation { userJoinedGameServer { userLeft(input: { ident: \"" .. id .. "\" }) { id } } }"
    })
end

function sendJoinedPlayer(id)
	HTTP({
        url=config.apiURL, 
        method="POST", 
        headers={
			['Authorization']="API-Key " .. config.apiKey
        },
		type="application/json",
        success=function( code, body, headers )
        end, 
        failed=function( err ) 
			error("Cannot send player joined", err)
        end,
        body=getUserJoinedMutation(id)
	})
end

function sendLeftPlayer(id)
	HTTP({
        url=config.apiURL, 
        method="POST", 
        headers={
			['Authorization']="API-Key " .. config.apiKey
        },
		type="application/json",
        success=function( code, body, headers )
        end, 
        failed=function( err ) 
			error("Cannot send player joined", err)
        end,
        body=getUserLeftMutation(id)
	})
end

info("Loading")
readConfig()

info("Listening")
gameevent.Listen( "player_connect" )
hook.Add("player_connect", "HandlePlayerConnect", function( data )
	info(string.format("Player %s connected", data.name))
	sendJoinedPlayer(data.networkid)
end)

gameevent.Listen( "player_disconnect" )
hook.Add("player_disconnect", "HandlePlayerDisconnect", function( data )
	info(string.format("Player %s disconnected", data.name))
	sendLeftPlayer(data.networkid)
end)